Order

Struct Order 

pub struct Order {
Show 13 fields pub base: Decimal, pub counter: Decimal, pub creation_timestamp: u64, pub expiration_timestamp: u64, pub completed_timestamp: u64, pub fee_base: Decimal, pub fee_counter: Decimal, pub limit_price: Decimal, pub limit_volume: Decimal, pub order_id: String, pub pair: TradingPair, pub state: OrderState, pub order_type: LimitOrderType,
}
Represents an order.

Fields

base: Decimal

The base account ID against which this order is made.

counter: Decimal

The counter account ID against which this order is made.

creation_timestamp: u64

The UNIX timestamp of creation of the order.

expiration_timestamp: u64

The UNIX timestamp of expiration of this order.

completed_timestamp: u64

The UNIX timestamp of completion of this order.

fee_base: Decimal

The base fee debited after the trade principal amount.

fee_counter: Decimal

The counter fee debited after the trade principal amount.

limit_price: Decimal

The limit price of this order.

limit_volume: Decimal

The limit volume of this order.

order_id: String

The ID of the order.

pair: TradingPair

The market trading pair.

state: OrderState

The state of the order.

order_type: LimitOrderType

The type of the order.