pub struct Order {Show 13 fields
pub base: Decimal,
pub counter: Decimal,
pub creation_timestamp: u64,
pub expiration_timestamp: u64,
pub completed_timestamp: u64,
pub fee_base: Decimal,
pub fee_counter: Decimal,
pub limit_price: Decimal,
pub limit_volume: Decimal,
pub order_id: String,
pub pair: TradingPair,
pub state: OrderState,
pub order_type: LimitOrderType,
}Expand description
Represents an order.
Fields
base: DecimalThe base account ID against which this order is made.
counter: DecimalThe counter account ID against which this order is made.
creation_timestamp: u64The UNIX timestamp of creation of the order.
expiration_timestamp: u64The UNIX timestamp of expiration of this order.
completed_timestamp: u64The UNIX timestamp of completion of this order.
fee_base: DecimalThe base fee debited after the trade principal amount.
fee_counter: DecimalThe counter fee debited after the trade principal amount.
limit_price: DecimalThe limit price of this order.
limit_volume: DecimalThe limit volume of this order.
order_id: StringThe ID of the order.
pair: TradingPairThe market trading pair.
state: OrderStateThe state of the order.
order_type: LimitOrderTypeThe type of the order.